package	Timestr;

=head1 NAME

Timestr - Convert between the UTC seconds and a time string.

$Id: Timestr.pm,v 1.1 2002/04/10 15:16:35 T.Shigetome Exp $

=head1 SYNOPSIS

	use	Timestr;
	print	LocalToGmtDate();

	use	Timestr;
	($sec,$min,$hour,$mday,$mon,$year,$wday) = AnalyzeDate("Mon, 01 Apr 2002 12:34:56 GMT");

=head1 DESCRIPTION

Convert between the UTC seconds and a time string.

=head2 METHOD

=over 4

=item GetTimeStr(I<$ltime>)

Convert a time string that formated along ASCII C's from local time.

=item LocalToGmtDate(I<$time>)

Convert a time string that formated along RFC1123 from local time.

=item AnalyzeDate(I<$time_string>)

Covert time as returned to a 7-element list from a time string.
Typically used as follows:

	($sec,$min,$hour,$mday,$mon,$year,$wday) = AnalyzeDate("Mon, 01 Apr 2002 12:34:56 GMT");

=item GetGmtStr(I<$sec>,I<$min>,I<$hour>,I<$mday>,I<$mon>,I<$year>,I<$wday>)

Convert a time string that formatted along RFC1123 from result of gmtime function.

=back

=head1 AUTHOR

Tetsuya Shigetome, E<lt>t_shigetome@muf.biglobe.ne.jpE<gt>.

=head1 HISTORY

=over 4

=item $Revision: 1.1 $

$Log: Timestr.pm,v $
Revision 1.1  2002/04/10 15:16:35  T.Shigetome
First release as Perl module version.


=back

=cut

require Exporter;
@Timestr::ISA = qw(Exporter);

# symbols to export by default
@Timestr::EXPORT = qw( GetTimeStr LocalToGmtDate AnalyzeDate GetGmtStr);
# symbols to export on request
@Timestr::EXPORT_OK = qw(&GetStr &LocalToGmtDate &AnalyzeDate &GetGmtStr);
$Timestr::VERSION = sprintf("%d.%02d", q$Revision: 1.1 $ =~ /(\d+)\.(\d+)/);

use strict;

%Timestr::Wkday = (
	"Sunday"	=>	0,	"Sun" => 0,	0 => "Sun",
	"Monday"	=>	1,	"Mon" => 1,	1 => "Mon",
	"Tuesday"	=>	2,	"Tue" => 2,	2 => "Tue",
	"Wednesday"	=>	3,	"Wed" => 3,	3 => "Wed",
	"Thursday"	=>	4,	"Thu" => 4,	4 => "Thu",
	"Friday"	=>	5,	"Fri" => 5,	5 => "Fri",
	"Saturday"	=>	6,	"Sat" => 6,	6 => "Sat",
);
%Timestr::Month = (
	"January"	=> 0,	"Jan"	=> 0,	0 =>	"Jan",
	"February"	=> 1,	"Feb"	=> 1,	1 =>	"Feb",
	"March"		=> 2,	"Mar"	=> 2,	2 =>	"Mar",
	"April"		=> 3,	"Apr"	=> 3,	3 =>	"Apr",
	"May"		=> 4,					4 =>	"May",
	"June"		=> 5,	"Jun"	=> 5,	5 =>	"Jun",
	"July"		=> 6,	"Jul"	=> 6,	6 =>	"Jul",
	"August"	=> 7,	"Aug"	=> 7,	7 =>	"Aug",
	"September"	=> 8,	"Sep"	=> 8,	8 =>	"Sep",
	"October"	=> 9,	"Oct"	=> 9,	9 =>	"Oct",
	"November"	=> 10,	"Nov"	=> 10,	10=>	"Nov",
	"December"	=> 11,	"Dec"	=> 11,	11=>	"Dec",
	);
$Timestr::gmadjust = 0;
sub GetTimeStr
{
my($ltime) = @_;
my($sec,$min,$hour,$mday,$mon,$year,$wday) = localtime($ltime);
	return sprintf("%s %s %02d %02d:%02d:%02d %d",$Timestr::Wkday{$wday},$Timestr::Month{$mon},$mday,$hour,$min,$sec,$year+1900);
}
sub AnalyzeDate
{
local($_) = @_;
my($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime();


	if( m/([A-W][a-z]{2,2}),\s*([0-9]{2,2})\s+([A-S][a-z]{2,2})\s+([0-9]{4,4})\s+([0-2][0-9]:[0-5][0-9]:[0-5][0-9])\s+GMT/ )
	{# Sun, 06 Nov 1994 08:49:37 GMT  ; RFC 822, updated by RFC 1123
		$wday = $Timestr::Wkday{$1};
		$mday = $2;
		$mon = $Timestr::Month{$3};
		$year = $4 - 1900;
		$isdst = 0;
		($hour,$min,$sec) = split(/:/,$5);
	}
	elsif( m/([A-W][a-z]{2,2})[a-z]*,\s*([0-9]{2,2})\-([A-S][a-z]{2,2})\-([0-9]{2,2})\s+([0-2][0-9]:[0-5][0-9]:[0-5][0-9])\s+GMT/ )
	{# Sunday, 06-Nov-94 08:49:37 GMT ; RFC 850, obsoleted by RFC 1036
		$wday = $Timestr::Wkday{$1};
		$mday = $2;
		$mon = $Timestr::Month{$3};
		$year = $4;
		$year += 100 if $year < 70;
		($hour,$min,$sec) = split(/:/,$5);
		$isdst = 0;
	}
	elsif( m/([A-W][a-z]{2,2})\s+([A-S][a-z]{2,2})\s+([0-9]{1,2})\s+([0-2][0-9]:[0-5][0-9]:[0-5][0-9])\s+([0-9]{4,4})/ )
	{# Sun Nov  6 08:49:37 1994       ; ANSI C's asctime() format
		$wday = $Timestr::Wkday{$1};
		$mon = $Timestr::Month{$2};
		$mday = $3;
		($hour,$min,$sec) = split(/:/,$4);
		$year = $5 - 1900;
		$isdst = 0;
	}
	return ($sec,$min,$hour,$mday,$mon,$year,$wday);
}
sub LocalToGmtDate
{
my($time) = @_;
my($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) = gmtime($time);
	$year = $year + 1900;
	return &GetGmtStr($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst);
}
sub GetGmtStr
{
my($sec,$min,$hour,$mday,$mon,$year,$wday) = @_;
	return sprintf("%s, %02d %s %4d %02d:%02d:%02d GMT",$Timestr::Wkday{$wday},$mday,$Timestr::Month{$mon},$year,$hour,$min,$sec);
}
1;
